# What is 3DOptix?
## The fastest, most intuitive, non-sequential, ray tracing, cloud-based, optical system simulation software.
3DOptix’s innovative GPU and cloud-based ray tracing engine can trace billions of rays per second, faster than any other simulation software on the market.

Our easy-to-use application enables you to easily design both simple and complex optical systems and make smart decisions based on real data.

3DOptix Warehouse is the first ever cloud-based workspace for sharing optical designs. With numerous designs available, the 3DOptix Warehouse offers engineers an unparalleled resource for exploring new ideas, discovering innovative solutions, and finding great starting points for their own designs.
